import type { GraphQLArgumentNormalizedConfig, GraphQLEnumTypeNormalizedConfig, GraphQLEnumValueConfig, GraphQLFieldNormalizedConfig, GraphQLInputFieldConfig, GraphQLInputObjectTypeNormalizedConfig, GraphQLInterfaceTypeNormalizedConfig, GraphQLNamedType, GraphQLObjectTypeNormalizedConfig, GraphQLScalarTypeNormalizedConfig, GraphQLType, GraphQLUnionTypeNormalizedConfig } from '../type/definition.js';
import type { GraphQLDirectiveNormalizedConfig } from '../type/directives.js';
import type { GraphQLSchemaNormalizedConfig } from '../type/schema.js';
/**
 * The set of GraphQL Schema Elements.
 */
export declare const SchemaElementKind: {
    readonly SCHEMA: "SCHEMA";
    readonly SCALAR: "SCALAR";
    readonly OBJECT: "OBJECT";
    readonly FIELD: "FIELD";
    readonly ARGUMENT: "ARGUMENT";
    readonly INTERFACE: "INTERFACE";
    readonly UNION: "UNION";
    readonly ENUM: "ENUM";
    readonly ENUM_VALUE: "ENUM_VALUE";
    readonly INPUT_OBJECT: "INPUT_OBJECT";
    readonly INPUT_FIELD: "INPUT_FIELD";
    readonly DIRECTIVE: "DIRECTIVE";
};
type SchemaElementKind = (typeof SchemaElementKind)[keyof typeof SchemaElementKind];
export interface SchemaContext {
    getType: <T extends GraphQLType>(type: T) => T;
    getNamedType: (typeName: string) => GraphQLNamedType;
    addNamedType: (type: GraphQLNamedType) => void;
    getNamedTypes: () => ReadonlyArray<GraphQLNamedType>;
}
type MappedGraphQLScalarTypeConfig = GraphQLScalarTypeNormalizedConfig<any, any>;
type EnsureThunks<T, ThunkFields extends keyof T> = {
    [K in keyof T]: K extends ThunkFields ? () => T[K] : T[K];
};
type MappedGraphQLObjectTypeConfig = EnsureThunks<GraphQLObjectTypeNormalizedConfig<any, any>, 'interfaces' | 'fields'>;
type MappedGraphQLInterfaceTypeConfig = EnsureThunks<GraphQLInterfaceTypeNormalizedConfig<any, any>, 'interfaces' | 'fields'>;
type MappedGraphQLUnionTypeConfig = EnsureThunks<GraphQLUnionTypeNormalizedConfig, 'types'>;
type MappedGraphQLEnumTypeConfig = EnsureThunks<GraphQLEnumTypeNormalizedConfig, 'values'>;
type MappedGraphQLInputObjectTypeConfig = EnsureThunks<GraphQLInputObjectTypeNormalizedConfig, 'fields'>;
type ScalarTypeConfigMapper = (scalarConfig: MappedGraphQLScalarTypeConfig) => MappedGraphQLScalarTypeConfig;
type ObjectTypeConfigMapper = (objectConfig: MappedGraphQLObjectTypeConfig) => MappedGraphQLObjectTypeConfig;
type FieldConfigMapper = (fieldConfig: GraphQLFieldNormalizedConfig<any, any>, parentTypeName: string) => GraphQLFieldNormalizedConfig<any, any>;
type ArgumentConfigMapper = (argConfig: GraphQLArgumentNormalizedConfig, fieldOrDirectiveName: string, parentTypeName?: string | undefined) => GraphQLArgumentNormalizedConfig;
type InterfaceTypeConfigMapper = (interfaceConfig: MappedGraphQLInterfaceTypeConfig) => MappedGraphQLInterfaceTypeConfig;
type UnionTypeConfigMapper = (unionConfig: MappedGraphQLUnionTypeConfig) => MappedGraphQLUnionTypeConfig;
type EnumTypeConfigMapper = (enumConfig: MappedGraphQLEnumTypeConfig) => MappedGraphQLEnumTypeConfig;
type EnumValueConfigMapper = (enumValueConfig: GraphQLEnumValueConfig, valueName: string, enumName: string) => GraphQLEnumValueConfig;
type InputObjectTypeConfigMapper = (inputObjectConfig: MappedGraphQLInputObjectTypeConfig) => MappedGraphQLInputObjectTypeConfig;
type InputFieldConfigMapper = (inputFieldConfig: GraphQLInputFieldConfig, inputFieldName: string, inputObjectTypeName: string) => GraphQLInputFieldConfig;
type DirectiveConfigMapper = (directiveConfig: GraphQLDirectiveNormalizedConfig) => GraphQLDirectiveNormalizedConfig;
type SchemaConfigMapper = (originalSchemaConfig: GraphQLSchemaNormalizedConfig) => GraphQLSchemaNormalizedConfig;
export interface MapperMap {
    [SchemaElementKind.SCALAR]?: ScalarTypeConfigMapper;
    [SchemaElementKind.OBJECT]?: ObjectTypeConfigMapper;
    [SchemaElementKind.FIELD]?: FieldConfigMapper;
    [SchemaElementKind.ARGUMENT]?: ArgumentConfigMapper;
    [SchemaElementKind.INTERFACE]?: InterfaceTypeConfigMapper;
    [SchemaElementKind.UNION]?: UnionTypeConfigMapper;
    [SchemaElementKind.ENUM]?: EnumTypeConfigMapper;
    [SchemaElementKind.ENUM_VALUE]?: EnumValueConfigMapper;
    [SchemaElementKind.INPUT_OBJECT]?: InputObjectTypeConfigMapper;
    [SchemaElementKind.INPUT_FIELD]?: InputFieldConfigMapper;
    [SchemaElementKind.DIRECTIVE]?: DirectiveConfigMapper;
    [SchemaElementKind.SCHEMA]?: SchemaConfigMapper;
}
/**
 * @internal
 */
export declare function mapSchemaConfig(schemaConfig: GraphQLSchemaNormalizedConfig, mapperMapFn: (context: SchemaContext) => MapperMap): GraphQLSchemaNormalizedConfig;
export {};
